@@ -4,7 +4,7 @@ import pickle
 import itertools 
 from shutil import copyfile
 
-from imagepreprocessing.file_operations import __read_from_file, __write_to_file
+from imagepreprocessing.internal_functions.file_operations import __read_from_file, __write_to_file
 
 # keras functions
 
@@ -265,13 +265,13 @@ def create_training_data_keras(source_path, save_path = None, image_size = (224,
         return x, y
 
 
-def make_prediction_from_directory_keras(images_path, keras_model_path, image_size = (224,224), print_output=True, model_summary=True, show_images=False, grayscale = False, files_to_exclude = [".DS_Store",""]):
+def make_prediction_from_directory_keras(images_path, keras_model, image_size = (224,224), print_output=True, model_summary=True, show_images=False, grayscale = False, files_to_exclude = [".DS_Store",""]):
     """
     Reads test data from directory resizes it and makes prediction with using a keras model
 
     # Arguments:
         images_path: source path of the test images see input format
-        keras_model_path: path of the keras model 
+        keras_model: a keras model object or path of the model 
         img_size (224): size of the images for resizing
         print_output (True): prints output
         model_summary (True): shows keras model summary 
@@ -323,8 +323,11 @@ def make_prediction_from_directory_keras(images_path, keras_model_path, image_si
         if exclude in images: 
             images.remove(exclude)
 
-    # load model
-    model = keras.models.load_model(keras_model_path)
+    # prepare model
+    if(isinstance(keras_model, keras.Model)):
+        model = keras_model
+    else:
+        model = keras.models.load_model(keras_model)
 
     # get all images
     for image in images:
@@ -367,13 +370,13 @@ def make_prediction_from_directory_keras(images_path, keras_model_path, image_si
     return predictions
 
 
-def make_prediction_from_array_keras(test_x, keras_model_path, print_output=True, model_summary=True, show_images=False):
+def make_prediction_from_array_keras(test_x, keras_model, print_output=True, model_summary=True, show_images=False):
     """
     makes prediction with using a keras model
 
     # Arguments:
         test_x: numpy array of images
-        keras_model_path: path of the keras model
+        keras_model: a keras model object or path of the model
         print_output (True): prints output
         model_summary (True): shows keras model summary 
         show_images (False): shows the predicted image
@@ -392,8 +395,11 @@ def make_prediction_from_array_keras(test_x, keras_model_path, print_output=True
     import keras
     import cv2
 
-    # load model
-    model = keras.models.load_model(keras_model_path)
+    # prepare model
+    if(isinstance(keras_model, keras.Model)):
+        model = keras_model
+    else:
+        model = keras.models.load_model(keras_model)
 
     # show model summary
     if(model_summary):
@@ -441,4 +447,85 @@ def make_prediction_from_array_keras(test_x, keras_model_path, print_output=True
                 raise TypeError(e,"""
             input array is not representable as image try with option show_images=False""")
 
-    return predictions
\ No newline at end of file
+    return predictions
+
+
+def create_history_graph_keras(history, title = "Training History", show = True, separate_train_val_plots=True, colors = {"train_accuracy":"blue", "train_loss":"orange", "val_accuracy":"green", "val_loss":"red"}):
+    """
+    # Arguments:
+        history: keras history object
+        title ("Training History"): plot title
+        show (True): show the plot
+        separate_plots (True): creates seperate plots for training an validation data
+        colors ({train_accuracy:"blue", train_loss:"orange", val_accuracy:"green", val_loss:"red"}): plot colors
+
+    # Returns:
+        matplotlib Axes object
+    """
+    import matplotlib.pyplot as plt
+    
+    is_validation_exists = False
+
+    if("acc" in history.history):
+        train_accuracy = history.history['acc']
+    elif("accuracy" in history.history):
+        train_accuracy = history.history['accuracy']
+    else:
+        raise ValueError("could not found accuracy value inside history object")
+
+    if("loss" in history.history):
+        train_loss = history.history['loss']
+    else:
+        raise ValueError("could not found loss value inside history object")
+
+    if("val_acc" in history.history):
+        val_accuracy = history.history['val_acc']
+        is_validation_exists = True
+    elif("val_accuracy" in history.history):
+        val_accuracy = history.history['val_accuracy']
+        is_validation_exists = True
+
+    if("val_loss" in history.history):
+        val_loss = history.history['val_loss']
+
+
+    epochs_nr = range(len(train_accuracy))
+
+    # create plots
+    if(separate_train_val_plots and is_validation_exists):
+        _, ax = plt.subplots(2)
+        
+        ax[0].plot(epochs_nr, train_accuracy, color=colors["train_accuracy"],  label='Training accuracy')
+        ax[0].plot(epochs_nr, train_loss, color=colors["train_loss"], label='Training loss')
+
+        if(is_validation_exists):
+            ax[1].plot(epochs_nr, val_accuracy, color=colors["val_accuracy"],  label='Validation accuracy')
+            ax[1].plot(epochs_nr, val_loss, color=colors["val_loss"], label='Validation loss')
+
+        # set options
+        for a in ax:
+            a.legend(prop={'size': 7})
+            a.set_xlabel('epochs')
+            a.grid()
+    else:
+        _, ax = plt.subplots()
+        
+        ax.plot(epochs_nr, train_accuracy, color=colors["train_accuracy"],  label='Training accuracy')
+        ax.plot(epochs_nr, train_loss, color=colors["train_loss"], label='Training loss')
+
+        if(is_validation_exists):
+            ax.plot(epochs_nr, val_accuracy, color=colors["val_accuracy"],  label='Validation accuracy')
+            ax.plot(epochs_nr, val_loss, color=colors["val_loss"], label='Validation loss')
+        
+        # set options
+        ax.legend(prop={'size': 7})
+        ax.set_xlabel('epochs')
+        ax.grid()
+
+    
+    plt.suptitle(title)
+
+    if(show):
+        plt.show()
+
+    return ax
